[−][src]Enum trade::api::hitbtc::errors::RestErrorKind
Translate an HTTP error code to an HitBTC error category.
Variants
BadRequestMalformed request, issue on the lib side or consumer side.
Authorisation required or failed.
ForbiddenAction is forbidden for API key.
TooManyRequestsThe client broke the request rate limit set by HitBTC. See HitBTC API documentation for each request weight and rate limits.
InternalErrorIssue on HitBTC side.
Service is down for maintenance.
TimeoutThe server did not respond in time. The order may have been executed or may have not.
Unknown(StatusCode)Unknown error.