[−][src]Struct trade::api::Trade
A liquidity consuming order.
Fields
price: TickUnit
Price in ticks.
size: TickUnit
Size consumed by the trade.
maker_side: Side
Side of the maker:
- if
Ask, then the maker was providing liquidity on the ask side, i.e. the consumer bought to the maker - if
Bid, then the maker was providing liquidity on the bid side, i.e. the consumer sold to the maker